@@ -1,11 +1,11 @@
 ##############################################################################
 # Net::Twitter - Perl OO interface to www.twitter.com
-# v2.00_01
+# v2.00_02
 # Copyright (c) 2009 Chris Thompson
 ##############################################################################
 
 package Net::Twitter;
-$VERSION = "2.00_01";
+$VERSION = "2.00_02";
 use warnings;
 use strict;
 
@@ -203,7 +203,7 @@ BEGIN {
             "uri"  => "/users/show/ID",
             "args" => {
                 "id"    => 1,
-                "email" => 1,
+                "email" => 0,
             },
         },
         "direct_messages" => {
@@ -468,6 +468,8 @@ BEGIN {
                 if ( ( !defined $method_def->{args}->{$argname} ) and ( !$self->{skip_arg_validation} ) ) {
                     warn "The field $argname is unknown and will not be passed";
                 } else {
+                    # drop arguments with undefined values (backcompat with v1.xx)
+                    next unless defined $args->{$argname};
                     if ( $method_def->{post} ) {
                         $finalargs->{$argname} = $args->{$argname};
                     } else {
@@ -499,8 +501,8 @@ BEGIN {
                 return unless $req->is_success;
                 return $req->content =~ /true/ ? 1 : 0;
             } else {
-                $self->{response_error} = JSON::Any->jsonToObj( $req->content );
-                return ( $req->is_success ) ? $self->{response_error} : undef;
+                $self->{response_error}   = $req->content;
+                return ( $req->is_success ) ? JSON::Any->jsonToObj( $req->content ) : undef;                
             }
           }
     }
@@ -515,7 +517,7 @@ Net::Twitter - Perl interface to twitter.com
 
 =head1 VERSION
 
-This document describes Net::Twitter version 2.00_01
+This document describes Net::Twitter version 2.00_02
 
 =head1 SYNOPSIS
 
@@ -1267,8 +1269,11 @@ supports should be supported by Net::Twitter. I hope.
 
 Please report any bugs or feature requests to
 C<bug-net-twitter@rt.cpan.org>, or through the web interface at
-L<hhttps://rt.cpan.org/Dist/Display.html?Queue=Net-Twitter>.
+L<https://rt.cpan.org/Dist/Display.html?Queue=Net-Twitter>.
 
+You can also join the Net::Twitter IRC channel at irc://irc.perl.org/net-twitter
+
+You can track Net::Twitter development at http://github.com/ct/net-twitter/tree/2.0
 
 =head1 AUTHOR
 
@@ -1279,7 +1284,7 @@ ups to Chris "perigrin" Prather for that.
        
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2008, Chris Thompson <cpan@cthompson.com>. All rights
+Copyright (c) 2009, Chris Thompson <cpan@cthompson.com>. All rights
 reserved.
 
 This module is free software; you can redistribute it and/or
